@@ -92,19 +92,18 @@ def squaremask(
     if offset_x + width > clip.width or offset_y + height > clip.height:
         raise CustomValueError('mask exceeds clip size!')
 
-    if aka_expr_available:
-        base_clip = clip.std.BlankClip(mask_format.id, 1, color=0, keep=True)
+    base_clip = clip.std.BlankClip(
+        width, height, mask_format.id, 1, color=0 if aka_expr_available else get_peak_value(clip), keep=True
+    )
 
+    if aka_expr_available:
         mask = norm_expr(
             base_clip, _get_region_expr(
-                clip, offset_y, clip.width - width - offset_x, offset_x, clip.height - height - offset_y,
+                clip, offset_x, clip.width - width - offset_x, offset_y, clip.height - height - offset_y,
                 'range_max x' if invert else 'x range_max'
             ), force_akarin=func
         )
     else:
-        base_clip = clip.std.BlankClip(
-            width, height, mask_format.id, 1, color=get_peak_value(clip), keep=True
-        )
         mask = base_clip.std.AddBorders(
             offset_x, clip.width - width - offset_x, offset_y, clip.height - height - offset_y
         )
@@ -128,6 +127,9 @@ def replace_squaremask(
 
     mask = squaremask(clipb[0], *mask_params, invert, func)
 
+    if ranges is None:
+        ranges = [(None, None)]
+
     if isinstance(blur_sigma, int):
         mask = box_blur(mask, blur_sigma)
     elif isinstance(blur_sigma, float):
